@@ -48,8 +48,6 @@
 #include <private/qdeclarativeanchors_p.h>
 #include <qdeclarativescriptstring.h>
 
-QT_BEGIN_HEADER
-
 QT_BEGIN_NAMESPACE
 
 QT_MODULE(Declarative)
@@ -294,6 +292,4 @@ QML_DECLARE_TYPE(QDeclarativeStateChangeScript)
 QML_DECLARE_TYPE(QDeclarativeAnchorSet)
 QML_DECLARE_TYPE(QDeclarativeAnchorChanges)
 
-QT_END_HEADER
-
 #endif // QDECLARATIVESTATEOPERATIONS_H
